PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/radial.h Source File

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

radial.h
Go to the documentation of this file.
1
6 #ifndef RADIAL_H
7 #define RADIAL_H
8
9 #include <complex.h>
10
11 double complex spherwave_planewave_overlap(double* center,
12 double* r, double* f, double** spline, int size,
13 double* lattice, double* reclattice, int l, int m,
14 double complex* x, int* fftg, double* k);
15
22 double complex offsite_wave_overlap(double* dcoord, double* r1, double* f1, double** spline1, int size1,
23 double* r2, double* f2, double** spline2, int size2,
24 double* lattice, int l1, int m1, int l2, int m2);
25
33 double complex reciprocal_offsite_wave_overlap(double* dcoord,
34 double* k1, double* f1, double** s1, int size1,
35 double* k2, double* f2, double** s2, int size2,
36 double* lattice, int l1, int m1, int l2, int m2);
37
38 #endif
spherwave_planewave_overlap
double complex spherwave_planewave_overlap(double *center, double *r, double *f, double **spline, int size, double *lattice, double *reclattice, int l, int m, double complex *x, int *fftg, double *k)
pawpyseed.core.gaunt.f
f
Definition: gaunt.py:28
pawpyseed.core.quadrature.x
list x
Definition: quadrature.py:9
reciprocal_offsite_wave_overlap
double complex reciprocal_offsite_wave_overlap(double *dcoord, double *k1, double *f1, double **s1, int size1, double *k2, double *f2, double **s2, int size2, double *lattice, int l1, int m1, int l2, int m2)
pawpyseed.core.rayleigh.k
int k
Definition: rayleigh.py:4
offsite_wave_overlap
double complex offsite_wave_overlap(double *dcoord, double *r1, double *f1, double **spline1, int size1, double *r2, double *f2, double **spline2, int size2, double *lattice, int l1, int m1, int l2, int m2)
pawpyseed.core.rayleigh.r
r
Definition: rayleigh.py:38